### Test 1 :

Launch `run_sender_agent.py` alone. 
    
Expected behavior : prints `"Send error detected"`.


### Test 2 :

Launch `run_receiver_agent.py`, then `run_sender_agent.py`.

Expected behavior : sender agent prints `"Task failure reported"`.
    